summaryrefslogtreecommitdiff
path: root/src/pal/tests/palsuite/c_runtime
diff options
context:
space:
mode:
Diffstat (limited to 'src/pal/tests/palsuite/c_runtime')
-rw-r--r--src/pal/tests/palsuite/c_runtime/CMakeLists.txt4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf/test5/CMakeLists.txt19
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf/test5/test5.cpp62
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf/test5/testinfo.dat12
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/CMakeLists.txt)1
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/sprintf_s.h (renamed from src/pal/tests/palsuite/c_runtime/sprintf/sprintf.h)32
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test1/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test1/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test1/test1.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test1/test1.cpp)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test1/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test1/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test10/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test10/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test10/test10.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test10/test10.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test10/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test10/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test11/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test11/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test11/test11.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test11/test11.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test11/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test11/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test12/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test12/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test12/test12.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test12/test12.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test12/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test12/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test13/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test13/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test13/test13.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test13/test13.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test13/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test13/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test14/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test14/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test14/test14.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test14/test14.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test14/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test14/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test15/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test15/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test15/test15.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test15/test15.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test15/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test15/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test16/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test16/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test16/test16.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test16/test16.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test16/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test16/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test17/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test17/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test17/test17.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test17/test17.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test17/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test17/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test18/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test18/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test18/test18.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test18/test18.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test18/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test18/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test19/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test19/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test19/test19.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test19/test19.cpp)11
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test19/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test19/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test2/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test2/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test2/test2.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test2/test2.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test2/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test2/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test3/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test3/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test3/test3.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test3/test3.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test3/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test3/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test4/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test4/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test4/test4.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test4/test4.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test4/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test4/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test6/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test6/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test6/test6.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test6/test6.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test6/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test6/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test7/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test7/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test7/test7.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test7/test7.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test7/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test7/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test8/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test8/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test8/test8.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test8/test8.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test8/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test8/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test9/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test9/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test9/test9.cpp (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test9/test9.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sprintf_s/test9/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test9/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/sscanf_s.h (renamed from src/pal/tests/palsuite/c_runtime/sscanf/sscanf.h)48
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test1/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test1/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test1/test1.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test1/test1.cpp)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test1/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test1/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test10/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test10/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test10/test10.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test10/test10.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test10/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test10/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test11/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test11/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test11/test11.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test11/test11.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test11/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test11/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test12/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test12/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test12/test12.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test12/test12.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test12/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test12/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test13/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test13/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test13/test13.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test13/test13.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test13/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test13/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test14/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test14/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test14/test14.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test14/test14.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test14/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test14/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test15/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test15/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test15/test15.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test15/test15.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test15/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test15/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test16/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test16/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test16/test16.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test16/test16.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test16/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test16/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test17/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test17/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test17/test17.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test17/test17.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test17/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test17/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test2/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test2/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test2/test2.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test2/test2.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test2/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test2/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test3/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test3/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test3/test3.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test3/test3.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test3/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test3/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test4/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test4/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test4/test4.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test4/test4.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test4/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test4/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test5/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test5/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test5/test5.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test5/test5.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test5/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test5/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test6/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test6/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test6/test6.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test6/test6.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test6/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test6/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test7/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test7/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test7/test7.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test7/test7.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test7/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test7/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test8/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test8/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test8/test8.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test8/test8.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test8/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sprintf/test8/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test9/CMakeLists.txt (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test9/CMakeLists.txt)0
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test9/test9.cpp (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test9/test9.cpp)4
-rw-r--r--src/pal/tests/palsuite/c_runtime/sscanf_s/test9/testinfo.dat (renamed from src/pal/tests/palsuite/c_runtime/sscanf/test9/testinfo.dat)6
-rw-r--r--src/pal/tests/palsuite/c_runtime/swscanf/swscanf.h4
-rw-r--r--src/pal/tests/palsuite/c_runtime/wcscat/test1/test1.cpp4
-rw-r--r--src/pal/tests/palsuite/c_runtime/wcscpy/test1/test1.cpp4
116 files changed, 225 insertions, 326 deletions
diff --git a/src/pal/tests/palsuite/c_runtime/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/CMakeLists.txt
index d2da52785e..cf062530eb 100644
--- a/src/pal/tests/palsuite/c_runtime/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/CMakeLists.txt
@@ -86,10 +86,10 @@ add_subdirectory(sin)
add_subdirectory(sinf)
add_subdirectory(sinh)
add_subdirectory(sinhf)
-add_subdirectory(sprintf)
+add_subdirectory(sprintf_s)
add_subdirectory(sqrt)
add_subdirectory(sqrtf)
-add_subdirectory(sscanf)
+add_subdirectory(sscanf_s)
add_subdirectory(strcat)
add_subdirectory(strchr)
add_subdirectory(strcmp)
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test5/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf/test5/CMakeLists.txt
deleted file mode 100644
index 5d7ce6cb6d..0000000000
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test5/CMakeLists.txt
+++ /dev/null
@@ -1,19 +0,0 @@
-cmake_minimum_required(VERSION 2.8.12.2)
-
-set(CMAKE_INCLUDE_CURRENT_DIR ON)
-
-set(SOURCES
- test5.cpp
-)
-
-add_executable(paltest_sprintf_test5
- ${SOURCES}
-)
-
-add_dependencies(paltest_sprintf_test5 coreclrpal)
-
-target_link_libraries(paltest_sprintf_test5
- pthread
- m
- coreclrpal
-)
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test5/test5.cpp b/src/pal/tests/palsuite/c_runtime/sprintf/test5/test5.cpp
deleted file mode 100644
index 1b52da77b6..0000000000
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test5/test5.cpp
+++ /dev/null
@@ -1,62 +0,0 @@
-// Licensed to the .NET Foundation under one or more agreements.
-// The .NET Foundation licenses this file to you under the MIT license.
-// See the LICENSE file in the project root for more information.
-
-/*============================================================================
-**
-** Source: test5.c
-**
-** Purpose: Test #5 for the sprintf function. Tests the count specifier (%n).
-**
-**
-**==========================================================================*/
-
-
-
-#include <palsuite.h>
-#include "../sprintf.h"
-
-/*
- * Depends on memcmp and strlen
- */
-
-
-int __cdecl main(int argc, char *argv[])
-{
- char *longStr =
- "really-long-string-that-just-keeps-going-on-and-on-and-on.."
- "..................useless-filler.................................."
- "..................useless-filler.................................."
- "..................useless-filler.................................."
- "%n bar";
- char *longResult =
- "really-long-string-that-just-keeps-going-on-and-on-and-on.."
- "..................useless-filler.................................."
- "..................useless-filler.................................."
- "..................useless-filler.................................."
- " bar";
-
- if (PAL_Initialize(argc, argv)!= 0)
- {
- return FAIL;
- }
-
- DoCountTest("foo %n bar", 4, "foo bar");
- DoCountTest(longStr, 257, longResult);
- DoCountTest("fo%n bar", 2, "fo bar");
- DoCountTest("%n", 0, "");
- DoCountTest("foo %#n bar", 4, "foo bar");
- DoCountTest("foo % n bar", 4, "foo bar");
- DoCountTest("foo %+n bar", 4, "foo bar");
- DoCountTest("foo %-n bar", 4, "foo bar");
- DoCountTest("foo %0n bar", 4, "foo bar");
- DoShortCountTest("foo %hn bar", 4, "foo bar");
- DoCountTest("foo %ln bar", 4, "foo bar");
- DoCountTest("foo %Ln bar", 4, "foo bar");
- DoCountTest("foo %I64n bar", 4, "foo bar");
- DoCountTest("foo %20.3n bar", 4, "foo bar");
-
- PAL_Terminate();
-
- return PASS;
-}
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test5/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf/test5/testinfo.dat
deleted file mode 100644
index 31e0537bd0..0000000000
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test5/testinfo.dat
+++ /dev/null
@@ -1,12 +0,0 @@
-# Licensed to the .NET Foundation under one or more agreements.
-# The .NET Foundation licenses this file to you under the MIT license.
-# See the LICENSE file in the project root for more information.
-
-Version = 1.0
-Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
-TYPE = DEFAULT
-EXE1 = test5
-Description
-= Tests sprintf with the count specifier
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/CMakeLists.txt
index cafb9536b0..8fe1cb60ac 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/CMakeLists.txt
@@ -14,7 +14,6 @@ add_subdirectory(test19)
add_subdirectory(test2)
add_subdirectory(test3)
add_subdirectory(test4)
-add_subdirectory(test5)
add_subdirectory(test6)
add_subdirectory(test7)
add_subdirectory(test8)
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test1/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test1/CMakeLists.txt
index ee0d90fe7f..ee0d90fe7f 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test1/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test1/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test1/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test1/testinfo.dat
index abe07445cc..255c534cdf 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test1/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test1/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test1
Description
-= General test to see if sprintf works correctly
+= General test to see if sprintf_s works correctly
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test10/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test10/CMakeLists.txt
index 1efad19dee..1efad19dee 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test10/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test10/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test10/test10.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test10/test10.cpp
index ae7dbfb177..bbda15a331 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test10/test10.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test10/test10.cpp
@@ -6,7 +6,7 @@
**
** Source: test10.c
**
-** Purpose: Test #10 for the sprintf function. Tests the octal specifier
+** Purpose: Test #10 for the sprintf_s function. Tests the octal specifier
** (%o).
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test10/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test10/testinfo.dat
index 7e854ed235..25ed554ea3 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test10/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test10/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test10
Description
-= Tests sscanf with wide characters
+= Tests sprintf_s with octal numbers
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test11/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test11/CMakeLists.txt
index f2f4da694c..f2f4da694c 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test11/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test11/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test11/test11.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test11/test11.cpp
index 0b5b5ab93d..7f4fca9f32 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test11/test11.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test11/test11.cpp
@@ -6,7 +6,7 @@
**
** Source: test11.c
**
-** Purpose: Test #11 for the sprintf function. Test the unsigned int
+** Purpose: Test #11 for the sprintf_s function. Test the unsigned int
** specifier (%u).
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test11/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test11/testinfo.dat
index 852bd3e7b6..3144f1290e 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test11/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test11/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test11
Description
-= Tests sprintf with unsigned numbers
+= Tests sprintf_s with unsigned numbers
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test12/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test12/CMakeLists.txt
index 361e91f9ae..361e91f9ae 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test12/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test12/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test12/test12.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test12/test12.cpp
index c2e778e494..759a41105b 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test12/test12.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test12/test12.cpp
@@ -6,7 +6,7 @@
**
** Source: test12.c
**
-** Purpose: Test #12 for the sprintf function. Tests the (lowercase)
+** Purpose: Test #12 for the sprintf_s function. Tests the (lowercase)
** hexadecimal specifier (%x)
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test12/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test12/testinfo.dat
index 5df91d0e6a..ed91cecc46 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test12/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test12/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test12
Description
-= Tests sprintf with hex numbers (lowercase)
+= Tests sprintf_s with hex numbers (lowercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test13/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test13/CMakeLists.txt
index d08e13b2ba..d08e13b2ba 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test13/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test13/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test13/test13.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test13/test13.cpp
index 0b4b7ed9ae..76250d058c 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test13/test13.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test13/test13.cpp
@@ -6,7 +6,7 @@
**
** Source: test13.c
**
-** Purpose: Test #13 for the sprintf function. Tests the (uppercase)
+** Purpose: Test #13 for the sprintf_s function. Tests the (uppercase)
** hexadecimal specifier (%X)
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test13/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test13/testinfo.dat
index 1c4c2fc26e..fd5f53017c 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test13/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test13/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test13
Description
-= Tests sscanf with floats (decimal notation)
+= Tests sprintf_s with hex numbers (uppercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test14/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test14/CMakeLists.txt
index 60ac2922d7..60ac2922d7 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test14/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test14/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test14/test14.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test14/test14.cpp
index 20e986a9c3..668edda433 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test14/test14.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test14/test14.cpp
@@ -6,7 +6,7 @@
**
** Source: test14.c
**
-** Purpose: Test #14 for the sprintf function. Tests the lowercase
+** Purpose: Test #14 for the sprintf_s function. Tests the lowercase
** exponential notation double specifier (%e)
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test14/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test14/testinfo.dat
index 97db6e4ffd..23cf423354 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test14/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test14/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test14
Description
-= Tests sscanf with floats (exponential notation, lowercase)
+= Tests sprintf_s with exponential format doubles (lowercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test15/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test15/CMakeLists.txt
index 57bba40e6c..57bba40e6c 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test15/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test15/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test15/test15.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test15/test15.cpp
index 34199b2eb3..61e0e362a1 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test15/test15.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test15/test15.cpp
@@ -6,7 +6,7 @@
**
** Source: test15.c
**
-** Purpose: Test #15 for the sprintf function. Tests the uppercase
+** Purpose: Test #15 for the sprintf_s function. Tests the uppercase
** exponential notation double specifier (%E)
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test15/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test15/testinfo.dat
index 30c2cf4b30..537e6d1db2 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test15/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test15/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test15
Description
-= Tests sscanf with floats (exponential notation, uppercase)
+= Tests sprintf_s with exponential format doubles (uppercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test16/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test16/CMakeLists.txt
index fc93e1a67d..fc93e1a67d 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test16/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test16/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test16/test16.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test16/test16.cpp
index c93b68bc2d..b237c98d5c 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test16/test16.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test16/test16.cpp
@@ -6,7 +6,7 @@
**
** Source: test16.c
**
-** Purpose: Test #16 for the sprintf function. Tests the decimal notation
+** Purpose: Test #16 for the sprintf_s function. Tests the decimal notation
** double specifier (%f)
**
**
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test16/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test16/testinfo.dat
index e18fab1ad8..4e98eccac2 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test16/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test16/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test16
Description
-= Tests sprintf with decimal point format doubles
+= Tests sprintf_s with decimal point format doubles
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test17/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test17/CMakeLists.txt
index dc5ff2bb30..dc5ff2bb30 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test17/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test17/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test17/test17.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test17/test17.cpp
index 643215b8f5..220555e5d4 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test17/test17.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test17/test17.cpp
@@ -6,7 +6,7 @@
**
** Source: test17.c
**
-** Purpose: Test #17 for the sprintf function. Tests the lowercase
+** Purpose: Test #17 for the sprintf_s function. Tests the lowercase
** shorthand notation double specifier (%g)
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test17/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test17/testinfo.dat
index e23be8541e..5e41e20d44 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test17/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test17/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test17
Description
-= Tests sscanf with floats (compact notation, uppercase)
+= Tests sprintf_s with compact format doubles (lowercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test18/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test18/CMakeLists.txt
index f6e1b09efa..f6e1b09efa 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test18/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test18/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test18/test18.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test18/test18.cpp
index fa88152479..2135a6f1e7 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test18/test18.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test18/test18.cpp
@@ -6,7 +6,7 @@
**
** Source: test18.c
**
-** Purpose: Test #18 for the sprintf function. Tests the uppercase
+** Purpose: Test #18 for the sprintf_s function. Tests the uppercase
** shorthand notation double specifier (%G)
**
**
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test18/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test18/testinfo.dat
index dfafa4bcf4..06ae3a632e 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test18/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test18/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test18
Description
-= Tests sprintf with compact format doubles (uppercase)
+= Tests sprintf_s with compact format doubles (uppercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test19/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test19/CMakeLists.txt
index 757288b694..757288b694 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test19/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test19/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test19/test19.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test19/test19.cpp
index bf3360c567..483c7167b1 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test19/test19.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test19/test19.cpp
@@ -6,7 +6,7 @@
**
** Source: test19.c
**
-** Purpose: Test #19 for the sprintf function. Tests the variable length
+** Purpose: Test #19 for the sprintf_s function. Tests the variable length
** precision argument.
**
**
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
@@ -33,13 +33,6 @@ int __cdecl main(int argc, char *argv[])
DoArgumentPrecTest("%.*s", 2, (void*)"bar", "bar", "ba", "ba");
DoArgumentPrecTest("%.*S", 2, (void*)convert("bar"), "bar", "ba", "ba");
- DoArgumentPrecTest("%.*n", 3, (void*)&n, "pointer to int", "", "");
- if (n != 0)
- {
- Fail("ERROR: Expected count parameter to resolve to %d, got %X\n",
- 0, n);
- }
-
DoArgumentPrecTest("%.*c", 0, (void*)'a', "a", "a", "a");
DoArgumentPrecTest("%.*c", 4, (void*)'a', "a", "a", "a");
DoArgumentPrecTest("%.*C", 0, (void*)'a', "a", "a", "a");
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test19/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test19/testinfo.dat
index ebd13025f6..7064c01771 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test19/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test19/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test19
Description
-= Tests sprintf with argument specified precision
+= Tests sprintf_s with argument specified precision
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test2/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test2/CMakeLists.txt
index d569263da4..d569263da4 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test2/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test2/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test2/test2.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test2/test2.cpp
index d50679a5a3..990f4f04a8 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test2/test2.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test2/test2.cpp
@@ -6,7 +6,7 @@
**
** Source: test2.c
**
-** Purpose: Test #2 for the sprintf function. Tests the string specifier
+** Purpose: Test #2 for the sprintf_s function. Tests the string specifier
** (%s).
**
**
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test2/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test2/testinfo.dat
index e8d0f53ff3..cce2dc67e7 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test2/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test2/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test2
Description
-= Tests sprintf with strings
+= Tests sprintf_s with strings
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test3/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test3/CMakeLists.txt
index 518c3f847a..518c3f847a 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test3/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test3/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test3/test3.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test3/test3.cpp
index ae52dbed08..c0dc8e1716 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test3/test3.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test3/test3.cpp
@@ -6,7 +6,7 @@
**
** Source: test3.c
**
-** Purpose: Test #3 for the sprintf function. Tests the wide string
+** Purpose: Test #3 for the sprintf_s function. Tests the wide string
** specifier (%S).
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test3/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test3/testinfo.dat
index c38a498225..cc8de0eae5 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test3/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test3/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test3
Description
-= Tests sscanf with bracketed set strings
+= Tests sprintf_s with wide strings
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test4/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test4/CMakeLists.txt
index 260def44aa..260def44aa 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test4/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test4/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test4/test4.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test4/test4.cpp
index 9660ffaa3a..46115ad5ae 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test4/test4.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test4/test4.cpp
@@ -6,7 +6,7 @@
**
** Source: test4.c
**
-** Purpose: Test #4 for the sprintf function. Tests the pointer
+** Purpose: Test #4 for the sprintf_s function. Tests the pointer
** specifier (%p).
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
*/
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test4/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test4/testinfo.dat
index 868056a6a5..f53f784991 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test4/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test4/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test4
Description
-= Tests sscanf with decimal numbers
+= Tests sprintf_s with pointers
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test6/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test6/CMakeLists.txt
index fce1f204fd..fce1f204fd 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test6/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test6/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test6/test6.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test6/test6.cpp
index c14e075475..c5fc804071 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test6/test6.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test6/test6.cpp
@@ -6,7 +6,7 @@
**
** Source: test6.c
**
-** Purpose: Test #6 for the sprintf function. Tests the char specifier (%c).
+** Purpose: Test #6 for the sprintf_s function. Tests the char specifier (%c).
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test6/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test6/testinfo.dat
index 037e4106ff..c5b93fc78c 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test6/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test6/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test6
Description
-= Tests sprintf with characters
+= Tests sprintf_s with characters
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test7/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test7/CMakeLists.txt
index 72a831ec89..72a831ec89 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test7/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test7/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test7/test7.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test7/test7.cpp
index 082bd20e6d..fd46ae9674 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test7/test7.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test7/test7.cpp
@@ -6,7 +6,7 @@
**
** Source: test7.c
**
-** Purpose: Test #7 for the sprintf function. Tests the wide char
+** Purpose: Test #7 for the sprintf_s function. Tests the wide char
** specifier (%C).
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test7/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test7/testinfo.dat
index a2730bc97c..647c9d80fd 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test7/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test7/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test7
Description
-= Tests sprintf with wide characters
+= Tests sprintf_s with wide characters
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test8/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test8/CMakeLists.txt
index c9522c1c9d..c9522c1c9d 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test8/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test8/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test8/test8.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test8/test8.cpp
index 9587c82c94..db02627bb0 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test8/test8.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test8/test8.cpp
@@ -6,7 +6,7 @@
**
** Source: test8.c
**
-** Purpose: Test #8 for the sprintf function. Tests the decimal
+** Purpose: Test #8 for the sprintf_s function. Tests the decimal
** specifier (%d).
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test8/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test8/testinfo.dat
index 2cbc31ad2a..524834e53e 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test8/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test8/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test8
Description
-= Tests sscanf with unsigned numbers
+= Tests sprintf_s with decimal numbers
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test9/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sprintf_s/test9/CMakeLists.txt
index e76fed4784..e76fed4784 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test9/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test9/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test9/test9.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test9/test9.cpp
index 98f5db6ec1..2e1c78ce68 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test9/test9.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test9/test9.cpp
@@ -6,7 +6,7 @@
**
** Source: test9.c
**
-** Purpose: Test #9 for the sprintf function. Tests the integer
+** Purpose: Test #9 for the sprintf_s function. Tests the integer
** specifier (%i).
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test9/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sprintf_s/test9/testinfo.dat
index e569e789cd..7c51443a3d 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test9/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test9/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sprintf_s
+Name = Positive Test for sprintf_s
TYPE = DEFAULT
EXE1 = test9
Description
-= Tests sprintf with integer numbers
+= Tests sprintf_s with integer numbers
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/CMakeLists.txt
index 59f39a5f58..59f39a5f58 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test1/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test1/CMakeLists.txt
index 97b8f570e3..97b8f570e3 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test1/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test1/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test1/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test1/testinfo.dat
index ef33ba9e13..76f592769f 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test1/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test1/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test1
Description
-= General test of sscanf
+= General test of sscanf_s
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test10/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test10/CMakeLists.txt
index afda216c6b..afda216c6b 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test10/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test10/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test10/test10.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test10/test10.cpp
index aac5be43ae..0c63c864ed 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test10/test10.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test10/test10.cpp
@@ -6,7 +6,7 @@
**
** Source: test10.c
**
-** Purpose: Tests sscanf with wide charactersn
+** Purpose: Tests sscanf_s with wide characters
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test10/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test10/testinfo.dat
index 70b7f3ab75..e048e700a0 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test10/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test10/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test10
Description
-= Tests sprintf with octal numbers
+= Tests sscanf_s with wide characters
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test11/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test11/CMakeLists.txt
index c8f98aeeef..c8f98aeeef 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test11/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test11/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test11/test11.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test11/test11.cpp
index 0e3db6cca0..8279f4b3f4 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test11/test11.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test11/test11.cpp
@@ -6,7 +6,7 @@
**
** Source: test11.c
**
-** Purpose: Tests sscanf with strings
+** Purpose: Tests sscanf_s with strings
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test11/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test11/testinfo.dat
index 60f5cc46a4..5a906ddf51 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test11/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test11/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test11
Description
-= Tests sscanf with strings
+= Tests sscanf_s with strings
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test12/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test12/CMakeLists.txt
index 0ecedc3285..0ecedc3285 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test12/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test12/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test12/test12.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test12/test12.cpp
index f800e452c0..e599534270 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test12/test12.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test12/test12.cpp
@@ -6,7 +6,7 @@
**
** Source: test12.c
**
-** Purpose: Tests sscanf with wide strings
+** Purpose: Tests sscanf_s with wide strings
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test12/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test12/testinfo.dat
index 3c453bf53a..569be983c0 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test12/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test12/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test12
Description
-= Tests sscanf with wide strings
+= Tests sscanf_s with wide strings
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test13/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test13/CMakeLists.txt
index 4566ec3338..4566ec3338 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test13/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test13/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test13/test13.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test13/test13.cpp
index 314604e3ac..4fc12bb751 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test13/test13.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test13/test13.cpp
@@ -6,7 +6,7 @@
**
** Source: test13.c
**
-** Purpose: Tests sscanf with floats (decimal notation)
+** Purpose: Tests sscanf_s with floats (decimal notation)
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test13/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test13/testinfo.dat
index 634817a791..651577befd 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test13/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test13/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test13
Description
-= Tests sprintf with hex numbers (uppercase)
+= Tests sscanf_s with floats (decimal notation)
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test14/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test14/CMakeLists.txt
index 557acf5bf8..557acf5bf8 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test14/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test14/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test14/test14.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test14/test14.cpp
index d1291a3b65..fc2fa2ee15 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test14/test14.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test14/test14.cpp
@@ -6,7 +6,7 @@
**
** Source: test14.c
**
-** Purpose: Tests sscanf with floats (exponential notation, lowercase)
+** Purpose: Tests sscanf_s with floats (exponential notation, lowercase)
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test14/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test14/testinfo.dat
index c7086efdbc..8e7338fd46 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test14/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test14/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test14
Description
-= Tests sprintf with exponential format doubles (lowercase)
+= Tests sscanf_s with floats (exponential notation, lowercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test15/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test15/CMakeLists.txt
index efde5c4a21..efde5c4a21 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test15/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test15/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test15/test15.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test15/test15.cpp
index fa51467d85..1eff995b86 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test15/test15.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test15/test15.cpp
@@ -6,7 +6,7 @@
**
** Source: test15.c
**
-** Purpose: Tests sscanf with floats (exponential notation, uppercase
+** Purpose: Tests sscanf_s with floats (exponential notation, uppercase
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test15/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test15/testinfo.dat
index 0a47c5321a..d713a73d81 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test15/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test15/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test15
Description
-= Tests sprintf with exponential format doubles (uppercase)
+= Tests sscanf_s with floats (exponential notation, uppercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test16/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test16/CMakeLists.txt
index 6757b0d78a..6757b0d78a 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test16/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test16/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test16/test16.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test16/test16.cpp
index 787b72ed0a..f202767448 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test16/test16.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test16/test16.cpp
@@ -6,7 +6,7 @@
**
** Source: test16.c
**
-** Purpose:Tests sscanf with floats (compact notation, lowercase)
+** Purpose:Tests sscanf_s with floats (compact notation, lowercase)
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test16/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test16/testinfo.dat
index 2c1dd42b70..669611945d 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test16/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test16/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test16
Description
-= Tests sscanf with floats (compact notation, lowercase)
+= Tests sscanf_s with floats (compact notation, lowercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test17/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test17/CMakeLists.txt
index 8ea4d5e3f6..8ea4d5e3f6 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test17/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test17/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test17/test17.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test17/test17.cpp
index c0dfd1699c..a18c3caff1 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test17/test17.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test17/test17.cpp
@@ -6,7 +6,7 @@
**
** Source: test17.c
**
-** Purpose: Tests sscanf with floats (compact notation, uppercase)
+** Purpose: Tests sscanf_s with floats (compact notation, uppercase)
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test17/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test17/testinfo.dat
index a723103e02..8ce4e93e1a 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test17/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test17/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test17
Description
-= Tests sprintf with compact format doubles (lowercase)
+= Tests sscanf_s with floats (compact notation, uppercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test2/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test2/CMakeLists.txt
index 4e36223a1d..4e36223a1d 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test2/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test2/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test2/test2.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test2/test2.cpp
index 1221124e3a..c9c79f67ea 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test2/test2.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test2/test2.cpp
@@ -6,7 +6,7 @@
**
** Source: test2.c
**
-** Purpose: Test to see if sscanf handles whitespace correctly
+** Purpose: Test to see if sscanf_s handles whitespace correctly
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
/*
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test2/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test2/testinfo.dat
index f5ee4b52d4..85fed244f9 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test2/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test2/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test2
Description
-= Test to see if sscanf handles whitespace correctly
+= Test to see if sscanf_s handles whitespace correctly
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test3/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test3/CMakeLists.txt
index 053a96ca0f..053a96ca0f 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test3/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test3/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test3/test3.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test3/test3.cpp
index 9d18991070..e1e45bdd70 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test3/test3.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test3/test3.cpp
@@ -6,7 +6,7 @@
**
** Source: test3.c
**
-** Purpose: Tests sscanf with bracketed set strings
+** Purpose: Tests sscanf_s with bracketed set strings
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test3/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test3/testinfo.dat
index 12e0a9cfb0..523d31e82e 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test3/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test3/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test3
Description
-= Tests sprintf with wide strings
+= Tests sscanf_s with bracketed set strings
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test4/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test4/CMakeLists.txt
index ae04bfef57..ae04bfef57 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test4/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test4/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test4/test4.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test4/test4.cpp
index dd0538bcfe..f8413ea7fd 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test4/test4.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test4/test4.cpp
@@ -6,7 +6,7 @@
**
** Source: test4.c
**
-** Purpose: Tests sscanf with decimal numbers
+** Purpose: Tests sscanf_s with decimal numbers
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test4/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test4/testinfo.dat
index bf7236dc32..2065f2bea2 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test4/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test4/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test4
Description
-= Tests sprintf with pointers
+= Tests sscanf_s with decimal numbers
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test5/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test5/CMakeLists.txt
index 33dcaffec3..33dcaffec3 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test5/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test5/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test5/test5.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test5/test5.cpp
index 0d45248af3..cdfefd860b 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test5/test5.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test5/test5.cpp
@@ -6,7 +6,7 @@
**
** Source: test5.c
**
-** Purpose: Tests sscanf with integer numbers
+** Purpose: Tests sscanf_s with integer numbers
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test5/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test5/testinfo.dat
index 8678dc8f5a..cb687c15cd 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test5/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test5/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test5
Description
-= Tests sscanf with integer numbers
+= Tests sscanf_s with integer numbers
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test6/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test6/CMakeLists.txt
index 1dd23c3cb1..1dd23c3cb1 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test6/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test6/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test6/test6.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test6/test6.cpp
index c45ea31b04..507b100e15 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test6/test6.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test6/test6.cpp
@@ -6,7 +6,7 @@
**
** Source: test6.c
**
-** Purpose: Tests sscanf with octal numbers
+** Purpose: Tests sscanf_s with octal numbers
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test6/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test6/testinfo.dat
index b2547a776a..9e518dddf2 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test6/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test6/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test6
Description
-= Tests sscanf with octal numbers
+= Tests sscanf_s with octal numbers
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test7/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test7/CMakeLists.txt
index 015a27b776..015a27b776 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test7/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test7/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test7/test7.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test7/test7.cpp
index 0899671d64..4093e009e1 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test7/test7.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test7/test7.cpp
@@ -6,7 +6,7 @@
**
** Source: test7.c
**
-** Purpose: Tests sscanf with hex numbers (lowercase)
+** Purpose: Tests sscanf_s with hex numbers (lowercase)
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test7/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test7/testinfo.dat
index 614333e650..8d6c182c90 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test7/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test7/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test7
Description
-= Tests sscanf with hex numbers (lowercase)
+= Tests sscanf_s with hex numbers (lowercase)
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test8/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test8/CMakeLists.txt
index aa41ab42a6..aa41ab42a6 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test8/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test8/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test8/test8.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test8/test8.cpp
index 53252f8929..23ef22a56a 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test8/test8.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test8/test8.cpp
@@ -6,7 +6,7 @@
**
** Source: test8.c
**
-** Purpose:Tests sscanf with unsigned number
+** Purpose:Tests sscanf_s with unsigned number
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
{
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test8/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test8/testinfo.dat
index adc0b66f06..0287a495d2 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test8/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test8/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section = C Runtime
-Function = sprintf
-Name = Positive Test for sprintf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test8
Description
-= Tests sprintf with decimal numbers
+= Tests sscanf_s with unsigned numbers
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test9/CMakeLists.txt b/src/pal/tests/palsuite/c_runtime/sscanf_s/test9/CMakeLists.txt
index b631fd40ea..b631fd40ea 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test9/CMakeLists.txt
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test9/CMakeLists.txt
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test9/test9.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test9/test9.cpp
index c5a2e0de5d..2c99c40e5d 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test9/test9.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test9/test9.cpp
@@ -6,7 +6,7 @@
**
** Source: test9.c
**
-** Purpose: Tests sscanf with characters
+** Purpose: Tests sscanf_s with characters
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test9/testinfo.dat b/src/pal/tests/palsuite/c_runtime/sscanf_s/test9/testinfo.dat
index c0ccc8a4c9..95f6c74ee2 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test9/testinfo.dat
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test9/testinfo.dat
@@ -4,9 +4,9 @@
Version = 1.0
Section =C Runtime
-Function = sscanf
-Name = Positive Test for sscanf
+Function = sscanf_s
+Name = Positive Test for sscanf_s
TYPE = DEFAULT
EXE1 = test9
Description
-= Tests sscanf with characters
+= Tests sscanf_s with characters
diff --git a/src/pal/tests/palsuite/c_runtime/swscanf/swscanf.h b/src/pal/tests/palsuite/c_runtime/swscanf/swscanf.h
index 6e40332fa6..6349b7dcd6 100644
--- a/src/pal/tests/palsuite/c_runtime/swscanf/swscanf.h
+++ b/src/pal/tests/palsuite/c_runtime/swscanf/swscanf.h
@@ -145,8 +145,8 @@ void DoI64NumTest(WCHAR *inputstr, const WCHAR *formatstr, INT64 checknum)
if (checknum != num)
{
- sprintf(buf, "%I64d", num);
- sprintf(check, "%I64d", checknum);
+ sprintf_s(buf, _countof(buf), "%I64d", num);
+ sprintf_s(check, _countof(check), "%I64d", checknum);
Fail("ERROR: scanned I64 number incorrectly from \"%s\" using \"%s\".\n"
"Expected %s, got %s.\n", convertC(inputstr),
convertC(formatstr), check, buf);
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/sprintf.h b/src/pal/tests/palsuite/c_runtime/sprintf_s/sprintf_s.h
index 6ec4a4d591..129b9db727 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/sprintf.h
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/sprintf_s.h
@@ -4,21 +4,21 @@
/*============================================================================
**
-** Source: sprintf.h
+** Source: sprintf_s.h
**
** Purpose: Containts common testing functions for sprintf
**
**
**==========================================================================*/
-#ifndef __SPRINTF_H__
-#define __SPRINTF_H__
+#ifndef __SPRINTF_S_H__
+#define __SPRINTF_S_H__
void DoStrTest(const char *formatstr, char* param, const char *checkstr)
{
char buf[256] = { 0 };
- sprintf(buf, formatstr, param);
+ sprintf_s(buf, _countof(buf), formatstr, param);
if (memcmp(buf, checkstr, strlen(checkstr) + 1) != 0)
{
Fail("ERROR: failed to insert string \"%s\" into \"%s\"\n"
@@ -31,7 +31,7 @@ void DoWStrTest(const char *formatstr, WCHAR* param, const char *checkstr)
{
char buf[256] = { 0 };
- sprintf(buf, formatstr, param);
+ sprintf_s(buf, _countof(buf), formatstr, param);
if (memcmp(buf, checkstr, strlen(checkstr) + 1) != 0)
{
Fail("ERROR: failed to insert wide string \"%s\" into \"%s\"\n"
@@ -45,7 +45,7 @@ void DoPointerTest(const char *formatstr, void* param, char* paramstr,
{
char buf[256] = { 0 };
- sprintf(buf, formatstr, param);
+ sprintf_s(buf, _countof(buf), formatstr, param);
if (memcmp(buf, checkstr1, strlen(checkstr1) + 1) != 0)
{
Fail("ERROR: failed to insert %s into \"%s\"\n"
@@ -59,7 +59,7 @@ void DoCountTest(const char *formatstr, int param, const char *checkstr)
char buf[512] = { 0 };
int n = -1;
- sprintf(buf, formatstr, &n);
+ sprintf_s(buf, _countof(buf), formatstr, &n);
if (n != param)
{
@@ -77,7 +77,7 @@ void DoShortCountTest(const char *formatstr, int param, const char *checkstr)
char buf[256] = { 0 };
short int n = -1;
- sprintf(buf, formatstr, &n);
+ sprintf_s(buf, _countof(buf), formatstr, &n);
if (n != param)
{
@@ -95,7 +95,7 @@ void DoCharTest(const char *formatstr, char param, const char *checkstr)
{
char buf[256] = { 0 };
- sprintf(buf, formatstr, param);
+ sprintf_s(buf, _countof(buf), formatstr, param);
if (memcmp(buf, checkstr, strlen(checkstr) + 1) != 0)
{
Fail("ERROR: failed to insert char \'%c\' (%d) into \"%s\"\n"
@@ -108,7 +108,7 @@ void DoWCharTest(const char *formatstr, WCHAR param, const char *checkstr)
{
char buf[256] = { 0 };
- sprintf(buf, formatstr, param);
+ sprintf_s(buf, _countof(buf), formatstr, param);
if (memcmp(buf, checkstr, strlen(checkstr) + 1) != 0)
{
Fail("ERROR: failed to insert wide char \'%c\' (%d) into \"%s\"\n"
@@ -121,7 +121,7 @@ void DoNumTest(const char *formatstr, int value, const char *checkstr)
{
char buf[256] = { 0 };
- sprintf(buf, formatstr, value);
+ sprintf_s(buf, _countof(buf), formatstr, value);
if (memcmp(buf, checkstr, strlen(checkstr) + 1) != 0)
{
Fail("ERROR: failed to insert %#x into \"%s\"\n"
@@ -134,7 +134,7 @@ void DoI64Test(const char *formatstr, INT64 value, char *valuestr, const char *c
{
char buf[256] = { 0 };
- sprintf(buf, formatstr, value);
+ sprintf_s(buf, _countof(buf), formatstr, value);
if (memcmp(buf, checkstr1, strlen(checkstr1) + 1) != 0)
{
Fail("ERROR: failed to insert %s into \"%s\"\n"
@@ -148,7 +148,7 @@ void DoDoubleTest(const char *formatstr, double value, const char *checkstr1,
{
char buf[256] = { 0 };
- sprintf(buf, formatstr, value);
+ sprintf_s(buf, _countof(buf), formatstr, value);
if (memcmp(buf, checkstr1, strlen(checkstr1) + 1) != 0 &&
memcmp(buf, checkstr2, strlen(checkstr2) + 1) != 0)
{
@@ -163,7 +163,7 @@ void DoArgumentPrecTest(const char *formatstr, int precision, void *param,
{
char buf[256];
- sprintf(buf, formatstr, precision, param);
+ sprintf_s(buf, _countof(buf), formatstr, precision, param);
if (memcmp(buf, checkstr1, strlen(checkstr1) + 1) != 0 &&
memcmp(buf, checkstr2, strlen(checkstr2) + 1) != 0)
{
@@ -179,7 +179,7 @@ void DoArgumentPrecDoubleTest(const char *formatstr, int precision, double param
{
char buf[256];
- sprintf(buf, formatstr, precision, param);
+ sprintf_s(buf, _countof(buf), formatstr, precision, param);
if (memcmp(buf, checkstr1, strlen(checkstr1) + 1) != 0 &&
memcmp(buf, checkstr2, strlen(checkstr2) + 1) != 0)
{
@@ -4,21 +4,21 @@
**
-** Purpose: Containts common testing functions for sprintf
+** Purpose: Containts common testing functions for sprintf_s
**
**
diff --git a/src/pal/tests/palsuite/c_runtime/sprintf/test1/test1.cpp b/src/pal/tests/palsuite/c_runtime/sprintf_s/test1/test1.cpp
index 42e27f263b..a289c07716 100644
--- a/src/pal/tests/palsuite/c_runtime/sprintf/test1/test1.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sprintf_s/test1/test1.cpp
@@ -6,7 +6,7 @@
**
** Source: test1.c
**
** Purpose: Test #1 for the sprintf function. A single, basic, test
** case with no formatting.
**
**
@@ -15,7 +15,7 @@
#include <palsuite.h>
-#include "../sprintf.h"
+#include "../sprintf_s.h"
/*
* Depends on memcmp and strlen
@@ -32,7 +32,7 @@ int __cdecl main(int argc, char *argv[])
}
- sprintf(buf, "hello world");
+ sprintf_s(buf, _countof(buf), "hello world");
if (memcmp(checkstr, buf, strlen(checkstr)+1) != 0)
{
@@ -6,7 +6,7 @@
** Source: test1.c
**
-** Purpose: Test #1 for the sprintf function. A single, basic, test
+** Purpose: Test #1 for the sprintf_s function. A single, basic, test
** case with no formatting.
**
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/sscanf.h b/src/pal/tests/palsuite/c_runtime/sscanf_s/sscanf_s.h
index 397f05cead..8a99d87cb4 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/sscanf.h
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/sscanf_s.h
@@ -4,15 +4,15 @@
/*============================================================================
**
-** Source: sscanf.h
+** Source: sscanf_s.h
**
** Purpose: Contains common testing functions for sscanf.h
**
**
**==========================================================================*/
-#ifndef __SSCANF_H__
-#define __SSCANF_H__
+#ifndef __SSCANF_S_H__
+#define __SSCANF_S_H__
void DoVoidTest(char *inputstr, const char *formatstr)
{
@@ -20,10 +20,10 @@ void DoVoidTest(char *inputstr, const char *formatstr)
int i;
int ret;
- ret = sscanf(inputstr, formatstr, buf);
+ ret = sscanf_s(inputstr, formatstr, buf);
if (ret != 0)
{
- Fail("ERROR: Expected sscanf to return 0, got %d.\n"
+ Fail("ERROR: Expected sscanf_s to return 0, got %d.\n"
"Using \"%s\" in \"%s\".\n", ret, inputstr, formatstr);
}
@@ -43,10 +43,10 @@ void DoStrTest(char *inputstr, const char *formatstr, const char *checkstr)
char buf[256] = { 0 };
int ret;
- ret = sscanf(inputstr, formatstr, buf);
+ ret = sscanf_s(inputstr, formatstr, buf, _countof(buf));
if (ret != 1)
{
- Fail("ERROR: Expected sscanf to return 1, got %d.\n"
+ Fail("ERROR: Expected sscanf_s to return 1, got %d.\n"
"Using \"%s\" in \"%s\".\n", ret, inputstr, formatstr);
}
@@ -64,10 +64,10 @@ void DoWStrTest(char *inputstr, const char *formatstr, const WCHAR *checkstr)
WCHAR buf[256] = { 0 };
int ret;
- ret = sscanf(inputstr, formatstr, buf);
+ ret = sscanf_s(inputstr, formatstr, buf, _countof(buf));
if (ret != 1)
{
- Fail("ERROR: Expected sscanf to return 1, got %d.\n"
+ Fail("ERROR: Expected sscanf_s to return 1, got %d.\n"
"Using \"%s\" in \"%s\".\n", ret, inputstr, formatstr);
}
@@ -85,10 +85,10 @@ void DoNumTest(char *inputstr, const char *formatstr, int checknum)
int num;
int ret;
- ret = sscanf(inputstr, formatstr, &num);
+ ret = sscanf_s(inputstr, formatstr, &num);
if (ret != 1)
{
- Fail("ERROR: Expected sscanf to return 1, got %d.\n"
+ Fail("ERROR: Expected sscanf_s to return 1, got %d.\n"
"Using \"%s\" in \"%s\".\n", ret, inputstr, formatstr);
}
@@ -104,10 +104,10 @@ void DoShortNumTest(char *inputstr, const char *formatstr, short checknum)
short num;
int ret;
- ret = sscanf(inputstr, formatstr, &num);
+ ret = sscanf_s(inputstr, formatstr, &num);
if (ret != 1)
{
- Fail("ERROR: Expected sscanf to return 1, got %d.\n"
+ Fail("ERROR: Expected sscanf_s to return 1, got %d.\n"
"Using \"%s\" in \"%s\".\n", ret, inputstr, formatstr);
}
@@ -125,17 +125,17 @@ void DoI64NumTest(char *inputstr, const char *formatstr, INT64 checknum)
INT64 num;
int ret;
- ret = sscanf(inputstr, formatstr, &num);
+ ret = sscanf_s(inputstr, formatstr, &num);
if (ret != 1)
{
- Fail("ERROR: Expected sscanf to return 1, got %d.\n"
+ Fail("ERROR: Expected sscanf_s to return 1, got %d.\n"
"Using \"%s\" in \"%s\".\n", ret, inputstr, formatstr);
}
if (checknum != num)
{
- sprintf(buf, "%I64d", num);
- sprintf(check, "%I64d", checknum);
+ sprintf_s(buf, _countof(buf), "%I64d", num);
+ sprintf_s(check, _countof(check), "%I64d", checknum);
Fail("ERROR: scanned I64 number incorrectly from \"%s\" using \"%s\".\n"
"Expected %s, got %s.\n", inputstr, formatstr, check, buf);
}
@@ -150,10 +150,10 @@ void DoCharTest(char *inputstr, const char *formatstr, char* checkchars, int num
for (i=0; i<256; i++)
buf[i] = (char)-1;
- ret = sscanf(inputstr, formatstr, buf);
+ ret = sscanf_s(inputstr, formatstr, buf, _countof(buf));
if (ret != 1)
{
- Fail("ERROR: Expected sscanf to return 1, got %d.\n"
+ Fail("ERROR: Expected sscanf_s to return 1, got %d.\n"
"Using \"%s\" in \"%s\".\n", ret, inputstr, formatstr);
}
@@ -183,10 +183,10 @@ void DoWCharTest(char *inputstr, const char *formatstr, WCHAR* checkchars, int n
for (i=0; i<256; i++)
buf[i] = (WCHAR)-1;
- ret = sscanf(inputstr, formatstr, buf);
+ ret = sscanf_s(inputstr, formatstr, buf, _countof(buf));
if (ret != 1)
{
- Fail("ERROR: Expected sscanf to return 1, got %d.\n"
+ Fail("ERROR: Expected sscanf_s to return 1, got %d.\n"
"Using \"%s\" in \"%s\".\n", ret, inputstr, formatstr);
}
@@ -218,12 +218,12 @@ void DoFloatTest(char *inputstr, const char *formatstr, float checkval)
for (i=0; i<256; i++)
buf[i] = (char)-1;
- ret = sscanf(inputstr, formatstr, buf);
+ ret = sscanf_s(inputstr, formatstr, buf);
val = *(float*)buf;
if (ret != 1)
{
- Fail("ERROR: Expected sscanf to return 1, got %d.\n"
+ Fail("ERROR: Expected sscanf_s to return 1, got %d.\n"
"Using \"%s\" in \"%s\".\n", ret, inputstr, formatstr);
}
@@ -4,15 +4,15 @@
**
-** Purpose: Contains common testing functions for sscanf.h
+** Purpose: Contains common testing functions for sscanf_s
**
**
diff --git a/src/pal/tests/palsuite/c_runtime/sscanf/test1/test1.cpp b/src/pal/tests/palsuite/c_runtime/sscanf_s/test1/test1.cpp
index c6f66a1d20..61313146e5 100644
--- a/src/pal/tests/palsuite/c_runtime/sscanf/test1/test1.cpp
+++ b/src/pal/tests/palsuite/c_runtime/sscanf_s/test1/test1.cpp
@@ -6,7 +6,7 @@
**
** Source: test1.c
**
** Purpose: General test of sscanf
**
**
**==========================================================================*/
@@ -14,7 +14,7 @@
#include <palsuite.h>
-#include "../sscanf.h"
+#include "../sscanf_s.h"
int __cdecl main(int argc, char *argv[])
@@ -38,7 +38,7 @@ int __cdecl main(int argc, char *argv[])
DoVoidTest("foo bar baz", "foo % bar %s");
DoVoidTest("foo baz bar", "foo% baz %s");
- ret = sscanf("foo bar baz", "foo bar %n", &num);
+ ret = sscanf_s("foo bar baz", "foo bar %n", &num);
if (ret != 0 || num != 8)
{
Fail("ERROR: Got incorrect values in scanning \"%s\" using \"%s\".\n"
@@ -6,7 +6,7 @@
** Source: test1.c
**
-** Purpose: General test of sscanf
+** Purpose: General test of sscanf_s
**
**
diff --git a/src/pal/tests/palsuite/c_runtime/wcscat/test1/test1.cpp b/src/pal/tests/palsuite/c_runtime/wcscat/test1/test1.cpp
index 789eebf5a3..e9a79d3880 100644
--- a/src/pal/tests/palsuite/c_runtime/wcscat/test1/test1.cpp
+++ b/src/pal/tests/palsuite/c_runtime/wcscat/test1/test1.cpp
@@ -18,7 +18,7 @@
#include <palsuite.h>
/*
* Notes: uses memcmp and the (pal) sprintf
*/
int __cdecl main(int argc, char *argv[])
@@ -60,7 +60,7 @@ int __cdecl main(int argc, char *argv[])
if (memcmp(dest, test, sizeof(test)) != 0)
{
- sprintf(buffer, "%S", dest);
+ sprintf_s(buffer, _countof(buffer), "%S", dest);
Fail("ERROR: Expected wcscat to give \"%s\", got \"%s\"\n",
"foo bar baz", buffer);
}
@@ -18,7 +18,7 @@
#include <palsuite.h>
/*
- * Notes: uses memcmp and the (pal) sprintf
+ * Notes: uses memcmp and the (pal) sprintf_s
*/
int __cdecl main(int argc, char *argv[])
diff --git a/src/pal/tests/palsuite/c_runtime/wcscpy/test1/test1.cpp b/src/pal/tests/palsuite/c_runtime/wcscpy/test1/test1.cpp
index 4e45c86516..2ecafa8307 100644
--- a/src/pal/tests/palsuite/c_runtime/wcscpy/test1/test1.cpp
+++ b/src/pal/tests/palsuite/c_runtime/wcscpy/test1/test1.cpp
@@ -15,7 +15,7 @@
#include <palsuite.h>
/*
* Notes: uses memcmp and sprintf.
*/
int __cdecl main(int argc, char *argv[])
@@ -37,7 +37,7 @@ int __cdecl main(int argc, char *argv[])
if (ret != dest || memcmp(dest, result, sizeof(result)) != 0)
{
- sprintf(buffer, "%S", dest);
+ sprintf_s(buffer, _countof(buffer), "%S", dest);
Fail("Expected wcscpy to give \"%s\" with a return value of %p, got \"%s\" "
"with a return value of %p.\n", "foo", dest, buffer, ret);
}
@@ -15,7 +15,7 @@
#include <palsuite.h>
/*
- * Notes: uses memcmp and sprintf.
+ * Notes: uses memcmp and sprintf_s.
*/
int __cdecl main(int argc, char *argv[])